# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/consensus/v1/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/consensus/v1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/consensus/v1/tx.proto\x12\x13\x63osmos.consensus.v1\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1e\x63ometbft/types/v1/params.proto\"\xec\x03\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12-\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1e.cometbft.types.v1.BlockParams\x12\x33\n\x08\x65vidence\x18\x03 \x01(\x0b\x32!.cometbft.types.v1.EvidenceParams\x12\x35\n\tvalidator\x18\x04 \x01(\x0b\x32\".cometbft.types.v1.ValidatorParams\x12\x42\n\x04\x61\x62\x63i\x18\x05 \x01(\x0b\x32\x1d.cometbft.types.v1.ABCIParamsB\x15\x18\x01\xda\xb4-\x0f\x63osmos-sdk 0.50\x12J\n\tsynchrony\x18\x06 \x01(\x0b\x32\".cometbft.types.v1.SynchronyParamsB\x13\xda\xb4-\x0f\x63osmos-sdk 0.52\x12\x46\n\x07\x66\x65\x61ture\x18\x07 \x01(\x0b\x32 .cometbft.types.v1.FeatureParamsB\x13\xda\xb4-\x0f\x63osmos-sdk 0.52:9\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*&cosmos-sdk/x/consensus/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\x85\x01\n\x03Msg\x12w\n\x0cUpdateParams\x12$.cosmos.consensus.v1.MsgUpdateParams\x1a,.cosmos.consensus.v1.MsgUpdateParamsResponse\"\x13\xca\xb4-\x0f\x63osmos-sdk 0.47\x1a\x05\x80\xe7\xb0*\x01\x42 Z\x1e\x63osmossdk.io/x/consensus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.consensus.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\036cosmossdk.io/x/consensus/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['abci']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['abci']._serialized_options = b'\030\001\332\264-\017cosmos-sdk 0.50'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['synchrony']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['synchrony']._serialized_options = b'\332\264-\017cosmos-sdk 0.52'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['feature']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['feature']._serialized_options = b'\332\264-\017cosmos-sdk 0.52'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*&cosmos-sdk/x/consensus/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSG'].methods_by_name['UpdateParams']._loaded_options = None
  _globals['_MSG'].methods_by_name['UpdateParams']._serialized_options = b'\312\264-\017cosmos-sdk 0.47'
  _globals['_MSGUPDATEPARAMS']._serialized_start=157
  _globals['_MSGUPDATEPARAMS']._serialized_end=649
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=651
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=676
  _globals['_MSG']._serialized_start=679
  _globals['_MSG']._serialized_end=812
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.crucible import params_pb2 as neurion_dot_crucible_dot_params__pb2
from neurion.crucible import task_pb2 as neurion_dot_crucible_dot_task__pb2
from neurion.crucible import submission_pb2 as neurion_dot_crucible_dot_submission__pb2
from neurion.crucible import plagiarism_report_pb2 as neurion_dot_crucible_dot_plagiarism__report__pb2
from neurion.crucible import creator_application_pb2 as neurion_dot_crucible_dot_creator__application__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cneurion/crucible/query.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1dneurion/crucible/params.proto\x1a\x1bneurion/crucible/task.proto\x1a!neurion/crucible/submission.proto\x1a(neurion/crucible/plagiarism_report.proto\x1a*neurion/crucible/creator_application.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.neurion.crucible.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x19\n\x17QueryGetCreatorsRequest\",\n\x18QueryGetCreatorsResponse\x12\x10\n\x08\x63reators\x18\x01 \x03(\t\"5\n\"QueryGetCreatorApplicationsRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"l\n#QueryGetCreatorApplicationsResponse\x12\x45\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32$.neurion.crucible.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"!\n\x13QueryGetTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"G\n\x14QueryGetTaskResponse\x12/\n\x04task\x18\x01 \x01(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryListAllTasksRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"\x8a\x01\n\x19QueryListAllTasksResponse\x12\x30\n\x05tasks\x18\x01 \x03(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"l\n\x1dQueryListTasksByStatusRequest\x12,\n\x06status\x18\x01 \x01(\x0e\x32\x1c.neurion.crucible.TaskStatus\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\x8f\x01\n\x1eQueryListTasksByStatusResponse\x12\x30\n\x05tasks\x18\x01 \x03(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\'\n\x19QueryGetSubmissionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"Y\n\x1aQueryGetSubmissionResponse\x12;\n\nsubmission\x18\x01 \x01(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n&QueryGetSubmissionByTaskCreatorRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\"\xb7\x01\n\'QueryGetSubmissionByTaskCreatorResponse\x12\x42\n\x11\x66inal_submissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x17provisional_submissions\x18\x02 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"2\n\x1fQueryGetSubmissionByTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"\xb0\x01\n QueryGetSubmissionByTaskResponse\x12\x42\n\x11\x66inal_submissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x17provisional_submissions\x18\x02 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n(QueryGetEncryptedProofOfOwnershipRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t\"?\n)QueryGetEncryptedProofOfOwnershipResponse\x12\x12\n\nciphertext\x18\x01 \x01(\t\"4\n\x1fQueryGetPlagiarismReportRequest\x12\x11\n\treport_id\x18\x01 \x01(\x04\"a\n QueryGetPlagiarismReportResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryGetTaskRewardRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\",\n\x1aQueryGetTaskRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"+\n)QueryGetPendingCreatorApplicationsRequest\"q\n*QueryGetPendingCreatorApplicationsResponse\x12\x43\n\napplicants\x18\x01 \x03(\x0b\x32$.neurion.crucible.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryGetTaskStakeRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\"*\n\x19QueryGetTaskStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\";\n(QueryGetUnscoredSubmissionsByTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"i\n)QueryGetUnscoredSubmissionsByTaskResponse\x12<\n\x0bsubmissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\xa5\x15\n\x05Query\x12w\n\x06Params\x12$.neurion.crucible.QueryParamsRequest\x1a%.neurion.crucible.QueryParamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/neurion/crucible/params\x12\x8c\x01\n\x0bGetCreators\x12).neurion.crucible.QueryGetCreatorsRequest\x1a*.neurion.crucible.QueryGetCreatorsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/neurion/crucible/get_creators\x12\xc3\x01\n\x16GetCreatorApplications\x12\x34.neurion.crucible.QueryGetCreatorApplicationsRequest\x1a\x35.neurion.crucible.QueryGetCreatorApplicationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/neurion/crucible/get_creator_applications/{creator}\x12\x81\x01\n\x07GetTask\x12%.neurion.crucible.QueryGetTaskRequest\x1a&.neurion.crucible.QueryGetTaskResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/neurion/crucible/get_task/{id}\x12\xa2\x01\n\x0cListAllTasks\x12*.neurion.crucible.QueryListAllTasksRequest\x1a+.neurion.crucible.QueryListAllTasksResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/crucible/list_all_tasks/{offset}/{limit}\x12\xc0\x01\n\x11ListTasksByStatus\x12/.neurion.crucible.QueryListTasksByStatusRequest\x1a\x30.neurion.crucible.QueryListTasksByStatusResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}\x12\x99\x01\n\rGetSubmission\x12+.neurion.crucible.QueryGetSubmissionRequest\x1a,.neurion.crucible.QueryGetSubmissionResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/neurion/crucible/get_submission/{id}\x12\xdf\x01\n\x1aGetSubmissionByTaskCreator\x12\x38.neurion.crucible.QueryGetSubmissionByTaskCreatorRequest\x1a\x39.neurion.crucible.QueryGetSubmissionByTaskCreatorResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}\x12\xb8\x01\n\x13GetSubmissionByTask\x12\x31.neurion.crucible.QueryGetSubmissionByTaskRequest\x1a\x32.neurion.crucible.QueryGetSubmissionByTaskResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_submission_by_task/{task_id}\x12\xe5\x01\n\x1cGetEncryptedProofOfOwnership\x12:.neurion.crucible.QueryGetEncryptedProofOfOwnershipRequest\x1a;.neurion.crucible.QueryGetEncryptedProofOfOwnershipResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}\x12\xb9\x01\n\x13GetPlagiarismReport\x12\x31.neurion.crucible.QueryGetPlagiarismReportRequest\x1a\x32.neurion.crucible.QueryGetPlagiarismReportResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/neurion/crucible/get_plagiarism_report/{report_id}\x12\xa6\x01\n\rGetTaskReward\x12+.neurion.crucible.QueryGetTaskRewardRequest\x1a,.neurion.crucible.QueryGetTaskRewardResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_task_reward/{task_id}/{user}\x12\xd6\x01\n\x1dGetPendingCreatorApplications\x12;.neurion.crucible.QueryGetPendingCreatorApplicationsRequest\x1a<.neurion.crucible.QueryGetPendingCreatorApplicationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_pending_creator_applications\x12\xa2\x01\n\x0cGetTaskStake\x12*.neurion.crucible.QueryGetTaskStakeRequest\x1a+.neurion.crucible.QueryGetTaskStakeResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/crucible/get_task_stake/{task_id}/{user}\x12\xdd\x01\n\x1cGetUnscoredSubmissionsByTask\x12:.neurion.crucible.QueryGetUnscoredSubmissionsByTaskRequest\x1a;.neurion.crucible.QueryGetUnscoredSubmissionsByTaskResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/crucible/get_unscored_submissions_by_task/{task_id}B\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applications']._loaded_options = None
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applications']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTALLTASKSRESPONSE'].fields_by_name['tasks']._loaded_options = None
  _globals['_QUERYLISTALLTASKSRESPONSE'].fields_by_name['tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE'].fields_by_name['tasks']._loaded_options = None
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE'].fields_by_name['tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONRESPONSE'].fields_by_name['submission']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONRESPONSE'].fields_by_name['submission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['final_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['final_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['provisional_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['provisional_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['final_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['final_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['provisional_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['provisional_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE'].fields_by_name['submissions']._loaded_options = None
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE'].fields_by_name['submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\032\022\030/neurion/crucible/params'
  _globals['_QUERY'].methods_by_name['GetCreators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreators']._serialized_options = b'\202\323\344\223\002 \022\036/neurion/crucible/get_creators'
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._serialized_options = b'\202\323\344\223\0026\0224/neurion/crucible/get_creator_applications/{creator}'
  _globals['_QUERY'].methods_by_name['GetTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002!\022\037/neurion/crucible/get_task/{id}'
  _globals['_QUERY'].methods_by_name['ListAllTasks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListAllTasks']._serialized_options = b'\202\323\344\223\0023\0221/neurion/crucible/list_all_tasks/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ListTasksByStatus']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListTasksByStatus']._serialized_options = b'\202\323\344\223\002B\022@/neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetSubmission']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmission']._serialized_options = b'\202\323\344\223\002\'\022%/neurion/crucible/get_submission/{id}'
  _globals['_QUERY'].methods_by_name['GetSubmissionByTaskCreator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmissionByTaskCreator']._serialized_options = b'\202\323\344\223\002F\022D/neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}'
  _globals['_QUERY'].methods_by_name['GetSubmissionByTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmissionByTask']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_submission_by_task/{task_id}'
  _globals['_QUERY'].methods_by_name['GetEncryptedProofOfOwnership']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetEncryptedProofOfOwnership']._serialized_options = b'\202\323\344\223\002F\022D/neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}'
  _globals['_QUERY'].methods_by_name['GetPlagiarismReport']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPlagiarismReport']._serialized_options = b'\202\323\344\223\0025\0223/neurion/crucible/get_plagiarism_report/{report_id}'
  _globals['_QUERY'].methods_by_name['GetTaskReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskReward']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_task_reward/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_pending_creator_applications'
  _globals['_QUERY'].methods_by_name['GetTaskStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskStake']._serialized_options = b'\202\323\344\223\0023\0221/neurion/crucible/get_task_stake/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetUnscoredSubmissionsByTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUnscoredSubmissionsByTask']._serialized_options = b'\202\323\344\223\002>\022</neurion/crucible/get_unscored_submissions_by_task/{task_id}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=346
  _globals['_QUERYPARAMSREQUEST']._serialized_end=366
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=368
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=442
  _globals['_QUERYGETCREATORSREQUEST']._serialized_start=444
  _globals['_QUERYGETCREATORSREQUEST']._serialized_end=469
  _globals['_QUERYGETCREATORSRESPONSE']._serialized_start=471
  _globals['_QUERYGETCREATORSRESPONSE']._serialized_end=515
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_start=517
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_end=570
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_start=572
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_end=680
  _globals['_QUERYGETTASKREQUEST']._serialized_start=682
  _globals['_QUERYGETTASKREQUEST']._serialized_end=715
  _globals['_QUERYGETTASKRESPONSE']._serialized_start=717
  _globals['_QUERYGETTASKRESPONSE']._serialized_end=788
  _globals['_QUERYLISTALLTASKSREQUEST']._serialized_start=790
  _globals['_QUERYLISTALLTASKSREQUEST']._serialized_end=847
  _globals['_QUERYLISTALLTASKSRESPONSE']._serialized_start=850
  _globals['_QUERYLISTALLTASKSRESPONSE']._serialized_end=988
  _globals['_QUERYLISTTASKSBYSTATUSREQUEST']._serialized_start=990
  _globals['_QUERYLISTTASKSBYSTATUSREQUEST']._serialized_end=1098
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE']._serialized_start=1101
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE']._serialized_end=1244
  _globals['_QUERYGETSUBMISSIONREQUEST']._serialized_start=1246
  _globals['_QUERYGETSUBMISSIONREQUEST']._serialized_end=1285
  _globals['_QUERYGETSUBMISSIONRESPONSE']._serialized_start=1287
  _globals['_QUERYGETSUBMISSIONRESPONSE']._serialized_end=1376
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORREQUEST']._serialized_start=1378
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORREQUEST']._serialized_end=1452
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE']._serialized_start=1455
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE']._serialized_end=1638
  _globals['_QUERYGETSUBMISSIONBYTASKREQUEST']._serialized_start=1640
  _globals['_QUERYGETSUBMISSIONBYTASKREQUEST']._serialized_end=1690
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE']._serialized_start=1693
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE']._serialized_end=1869
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPREQUEST']._serialized_start=1871
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPREQUEST']._serialized_end=1945
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPRESPONSE']._serialized_start=1947
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPRESPONSE']._serialized_end=2010
  _globals['_QUERYGETPLAGIARISMREPORTREQUEST']._serialized_start=2012
  _globals['_QUERYGETPLAGIARISMREPORTREQUEST']._serialized_end=2064
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE']._serialized_start=2066
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE']._serialized_end=2163
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_start=2165
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_end=2223
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_start=2225
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_end=2269
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_start=2271
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_end=2314
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_start=2316
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_end=2429
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_start=2431
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_end=2488
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_start=2490
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_end=2532
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKREQUEST']._serialized_start=2534
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKREQUEST']._serialized_end=2593
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE']._serialized_start=2595
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE']._serialized_end=2700
  _globals['_QUERY']._serialized_start=2703
  _globals['_QUERY']._serialized_end=5428
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/store/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tendermint/store/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/store/types.proto\x12\x10tendermint.store\"/\n\x0f\x42lockStoreState\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x42\x39Z7github.com/tendermint/tendermint/proto/tendermint/storeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.store.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/store'
  _globals['_BLOCKSTORESTATE']._serialized_start=50
  _globals['_BLOCKSTORESTATE']._serialized_end=97
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from typing import Optional

from neurionpy.protos.neurion.fusion.query_pb2 import QueryParamsRequest, QueryParamsResponse
from neurionpy.synapse.tx_helpers import SubmittedTx
from neurionpy.synapse.wallet import Wallet


class FusionQuery(ABC):
    """Sanctum abstract class."""

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query the parameters of bank module.
        :param request: QueryParamsRequest
        :return: QueryParamsResponse
        """


class FusionMessage(ABC):
    """Fusion abstract class."""





from abc import ABC, abstractmethod
from typing import Optional

from neurionpy.protos.neurion.sanctum.query_pb2 import QueryParamsRequest, QueryParamsResponse
from neurionpy.protos.neurion.sanctum.tx_pb2 import MsgSubmitDatasetApplication, MsgSubmitDatasetApplicationResponse
from neurionpy.synapse.tx_helpers import SubmittedTx
from neurionpy.synapse.wallet import Wallet


class SanctumQuery(ABC):
    """Sanctum abstract class."""

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query the parameters of bank module.
        :param request: QueryParamsRequest
        :return: QueryParamsResponse
        """


class SanctumMessage(ABC):
    """Sanctum abstract class."""

    @abstractmethod
    def SubmitDatasetApplication(self, message: MsgSubmitDatasetApplication,
                                 memo: Optional[str] = None,
                                 gas_limit: Optional[int] = None) -> SubmittedTx:
        """
        Submit dataset application.
        :param message: MsgSubmitDatasetApplication
        :param memo: Optional[str]
        :param gas_limit: Optional[int]
        :raises RuntimeError: If unable to parse the value
        :return: SubmittedTx
        """



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.ibc.core.channel.interface import IBCCoreChannel  # type: ignore
from neurionpy.protos.ibc.core.channel.v1.query_pb2 import (
    QueryChannelClientStateRequest,
    QueryChannelClientStateResponse,
    QueryChannelConsensusStateRequest,
    QueryChannelConsensusStateResponse,
    QueryChannelRequest,
    QueryChannelResponse,
    QueryChannelsRequest,
    QueryChannelsResponse,
    QueryConnectionChannelsRequest,
    QueryConnectionChannelsResponse,
    QueryNextSequenceReceiveRequest,
    QueryNextSequenceReceiveResponse,
    QueryPacketAcknowledgementRequest,
    QueryPacketAcknowledgementResponse,
    QueryPacketAcknowledgementsRequest,
    QueryPacketAcknowledgementsResponse,
    QueryPacketCommitmentRequest,
    QueryPacketCommitmentResponse,
    QueryPacketCommitmentsRequest,
    QueryPacketCommitmentsResponse,
    QueryPacketReceiptRequest,
    QueryPacketReceiptResponse,
    QueryUnreceivedAcksRequest,
    QueryUnreceivedAcksResponse,
    QueryUnreceivedPacketsRequest,
    QueryUnreceivedPacketsResponse,
)


class IBCCoreChannelRestClient(IBCCoreChannel):
    """IBC Core Channel REST client."""

    API_URL = "/ibc/core/channel/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def Channel(self, request: QueryChannelRequest) -> QueryChannelResponse:
        """
        Channel queries an IBC Channel.

        :param request: QueryChannelRequest
        :return: QueryChannelResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}"
        )
        return Parse(json_response, QueryChannelResponse())

    def Channels(self, request: QueryChannelsRequest) -> QueryChannelsResponse:
        """
        Channels queries all the IBC channels of a chain.

        :param request: QueryChannelsRequest
        :return: QueryChannelsResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/channels", request)
        return Parse(json_response, QueryChannelsResponse())

    def ConnectionChannels(
        self, request: QueryConnectionChannelsRequest
    ) -> QueryConnectionChannelsResponse:
        """
        ConnectionChannels queries all the channels associated with a connection.

        :param request: QueryConnectionChannelsRequest
        :return: QueryConnectionChannelsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/connections/{request.connection}/channels", request
        )
        return Parse(json_response, QueryConnectionChannelsResponse())

    def ChannelClientState(
        self, request: QueryChannelClientStateRequest
    ) -> QueryChannelClientStateResponse:
        """
        ChannelClientState queries for the client state for the channel associated with the provided channel identifiers.

        :param request: QueryChannelClientStateRequest
        :return: QueryChannelClientStateResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/client_state"
        )
        return Parse(json_response, QueryChannelClientStateResponse())

    def ChannelConsensusState(
        self, request: QueryChannelConsensusStateRequest
    ) -> QueryChannelConsensusStateResponse:
        """
        ChannelConsensusState queries for the consensus state for the channel associated with the provided channel identifiers.

        :param request: QueryChannelConsensusStateRequest
        :return: QueryChannelConsensusStateResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/consensus_state/revision/{request.revision_number}/height/{request.revision_height}"
        )
        return Parse(json_response, QueryChannelConsensusStateResponse())

    def PacketCommitment(
        self, request: QueryPacketCommitmentRequest
    ) -> QueryPacketCommitmentResponse:
        """
        PacketCommitment queries a stored packet commitment hash.

        :param request: QueryPacketCommitmentRequest
        :return: QueryPacketCommitmentResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/packet_commitments/{request.sequence}"
        )
        return Parse(json_response, QueryPacketCommitmentResponse())

    def PacketCommitments(
        self, request: QueryPacketCommitmentsRequest
    ) -> QueryPacketCommitmentsResponse:
        """
        PacketCommitments returns all the packet commitments hashes associated with a channel.

        :param request: QueryPacketCommitmentsRequest
        :return: QueryPacketCommitmentsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/packet_commitments",
            request,
        )
        return Parse(json_response, QueryPacketCommitmentsResponse())

    def PacketReceipt(
        self, request: QueryPacketReceiptRequest
    ) -> QueryPacketReceiptResponse:
        """
        PacketReceipt queries if a given packet sequence has been received on the queried chain.

        :param request: QueryPacketReceiptRequest
        :return: QueryPacketReceiptResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/packet_receipts/{request.sequence}"
        )
        return Parse(json_response, QueryPacketReceiptResponse())

    def PacketAcknowledgement(
        self, request: QueryPacketAcknowledgementRequest
    ) -> QueryPacketAcknowledgementResponse:
        """
        PacketAcknowledgement queries a stored packet acknowledgment hash.

        :param request: QueryPacketAcknowledgementRequest
        :return: QueryPacketAcknowledgementResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/packet_acks/{request.sequence}"
        )
        return Parse(json_response, QueryPacketAcknowledgementResponse())

    def PacketAcknowledgements(
        self, request: QueryPacketAcknowledgementsRequest
    ) -> QueryPacketAcknowledgementsResponse:
        """
        PacketAcknowledgements returns all the packet acknowledgments associated with a channel.

        :param request: QueryPacketAcknowledgementsRequest
        :return: QueryPacketAcknowledgementsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/packet_acknowledgements",
            request,
        )
        return Parse(json_response, QueryPacketAcknowledgementsResponse())

    def UnreceivedPackets(
        self, request: QueryUnreceivedPacketsRequest
    ) -> QueryUnreceivedPacketsResponse:
        """
        UnreceivedPackets returns all the unreceived IBC packets associated with a channel and sequences.

        :param request: QueryUnreceivedPacketsRequest
        :return: QueryUnreceivedPacketsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/packet_commitments/{','.join(map(str,request.packet_commitment_sequences))}/unreceived_packets",
            request,
        )
        return Parse(json_response, QueryUnreceivedPacketsResponse())

    def UnreceivedAcks(
        self, request: QueryUnreceivedAcksRequest
    ) -> QueryUnreceivedAcksResponse:
        """
        UnreceivedAcks returns all the unreceived IBC acknowledgments associated with a channel and sequences.

        :param request: QueryUnreceivedAcksRequest
        :return: QueryUnreceivedAcksResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/packet_commitments/{','.join(map(str,request.packet_ack_sequences))}/unreceived_acks",
            request,
        )
        return Parse(json_response, QueryUnreceivedAcksResponse())

    def NextSequenceReceive(
        self, request: QueryNextSequenceReceiveRequest
    ) -> QueryNextSequenceReceiveResponse:
        """
        NextSequenceReceive returns the next receive sequence for a given channel.

        :param request: QueryNextSequenceReceiveRequest
        :return: QueryNextSequenceReceiveResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/channels/{request.channel_id}/ports/{request.port_id}/next_sequence"
        )
        return Parse(json_response, QueryNextSequenceReceiveResponse())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/bank/v1beta1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/bank/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/bank/v1beta1/query.proto\x12\x13\x63osmos.bank.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\"?\n\x13QueryBalanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"B\n\x14QueryBalanceResponse\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"p\n\x17QueryAllBalancesRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb6\x01\n\x18QueryAllBalancesResponse\x12]\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"_\n\x17QueryTotalSupplyRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb4\x01\n\x18QueryTotalSupplyResponse\x12[\n\x06supply\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"%\n\x14QuerySupplyOfRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"H\n\x15QuerySupplyOfResponse\x12/\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.bank.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"X\n\x1aQueryDenomsMetadataRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x92\x01\n\x1bQueryDenomsMetadataResponse\x12\x36\n\tmetadatas\x18\x01 \x03(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"*\n\x19QueryDenomMetadataRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"S\n\x1aQueryDenomMetadataResponse\x12\x35\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\x32\xb3\x08\n\x05Query\x12\x98\x01\n\x07\x42\x61lance\x12(.cosmos.bank.v1beta1.QueryBalanceRequest\x1a).cosmos.bank.v1beta1.QueryBalanceResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/bank/v1beta1/balances/{address}/by_denom\x12\x9b\x01\n\x0b\x41llBalances\x12,.cosmos.bank.v1beta1.QueryAllBalancesRequest\x1a-.cosmos.bank.v1beta1.QueryAllBalancesResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/bank/v1beta1/balances/{address}\x12\x8f\x01\n\x0bTotalSupply\x12,.cosmos.bank.v1beta1.QueryTotalSupplyRequest\x1a-.cosmos.bank.v1beta1.QueryTotalSupplyResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/supply\x12\x8e\x01\n\x08SupplyOf\x12).cosmos.bank.v1beta1.QuerySupplyOfRequest\x1a*.cosmos.bank.v1beta1.QuerySupplyOfResponse\"+\x82\xd3\xe4\x93\x02%\x12#/cosmos/bank/v1beta1/supply/{denom}\x12\x80\x01\n\x06Params\x12\'.cosmos.bank.v1beta1.QueryParamsRequest\x1a(.cosmos.bank.v1beta1.QueryParamsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/params\x12\xa6\x01\n\rDenomMetadata\x12..cosmos.bank.v1beta1.QueryDenomMetadataRequest\x1a/.cosmos.bank.v1beta1.QueryDenomMetadataResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/bank/v1beta1/denoms_metadata/{denom}\x12\xa1\x01\n\x0e\x44\x65nomsMetadata\x12/.cosmos.bank.v1beta1.QueryDenomsMetadataRequest\x1a\x30.cosmos.bank.v1beta1.QueryDenomsMetadataResponse\",\x82\xd3\xe4\x93\x02&\x12$/cosmos/bank/v1beta1/denoms_metadataB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _globals['_QUERYBALANCEREQUEST']._loaded_options = None
  _globals['_QUERYBALANCEREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYALLBALANCESREQUEST']._loaded_options = None
  _globals['_QUERYALLBALANCESREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYALLBALANCESRESPONSE'].fields_by_name['balances']._loaded_options = None
  _globals['_QUERYALLBALANCESRESPONSE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERYTOTALSUPPLYREQUEST']._loaded_options = None
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYTOTALSUPPLYRESPONSE'].fields_by_name['supply']._loaded_options = None
  _globals['_QUERYTOTALSUPPLYRESPONSE'].fields_by_name['supply']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERYSUPPLYOFRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYSUPPLYOFRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDENOMSMETADATARESPONSE'].fields_by_name['metadatas']._loaded_options = None
  _globals['_QUERYDENOMSMETADATARESPONSE'].fields_by_name['metadatas']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDENOMMETADATARESPONSE'].fields_by_name['metadata']._loaded_options = None
  _globals['_QUERYDENOMMETADATARESPONSE'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Balance']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Balance']._serialized_options = b'\202\323\344\223\0022\0220/cosmos/bank/v1beta1/balances/{address}/by_denom'
  _globals['_QUERY'].methods_by_name['AllBalances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllBalances']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/bank/v1beta1/balances/{address}'
  _globals['_QUERY'].methods_by_name['TotalSupply']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TotalSupply']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/bank/v1beta1/supply'
  _globals['_QUERY'].methods_by_name['SupplyOf']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SupplyOf']._serialized_options = b'\202\323\344\223\002%\022#/cosmos/bank/v1beta1/supply/{denom}'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/bank/v1beta1/params'
  _globals['_QUERY'].methods_by_name['DenomMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomMetadata']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/bank/v1beta1/denoms_metadata/{denom}'
  _globals['_QUERY'].methods_by_name['DenomsMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomsMetadata']._serialized_options = b'\202\323\344\223\002&\022$/cosmos/bank/v1beta1/denoms_metadata'
  _globals['_QUERYBALANCEREQUEST']._serialized_start=216
  _globals['_QUERYBALANCEREQUEST']._serialized_end=279
  _globals['_QUERYBALANCERESPONSE']._serialized_start=281
  _globals['_QUERYBALANCERESPONSE']._serialized_end=347
  _globals['_QUERYALLBALANCESREQUEST']._serialized_start=349
  _globals['_QUERYALLBALANCESREQUEST']._serialized_end=461
  _globals['_QUERYALLBALANCESRESPONSE']._serialized_start=464
  _globals['_QUERYALLBALANCESRESPONSE']._serialized_end=646
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_start=648
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_end=743
  _globals['_QUERYTOTALSUPPLYRESPONSE']._serialized_start=746
  _globals['_QUERYTOTALSUPPLYRESPONSE']._serialized_end=926
  _globals['_QUERYSUPPLYOFREQUEST']._serialized_start=928
  _globals['_QUERYSUPPLYOFREQUEST']._serialized_end=965
  _globals['_QUERYSUPPLYOFRESPONSE']._serialized_start=967
  _globals['_QUERYSUPPLYOFRESPONSE']._serialized_end=1039
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1041
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1061
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1063
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1135
  _globals['_QUERYDENOMSMETADATAREQUEST']._serialized_start=1137
  _globals['_QUERYDENOMSMETADATAREQUEST']._serialized_end=1225
  _globals['_QUERYDENOMSMETADATARESPONSE']._serialized_start=1228
  _globals['_QUERYDENOMSMETADATARESPONSE']._serialized_end=1374
  _globals['_QUERYDENOMMETADATAREQUEST']._serialized_start=1376
  _globals['_QUERYDENOMMETADATAREQUEST']._serialized_end=1418
  _globals['_QUERYDENOMMETADATARESPONSE']._serialized_start=1420
  _globals['_QUERYDENOMMETADATARESPONSE']._serialized_end=1503
  _globals['_QUERY']._serialized_start=1506
  _globals['_QUERY']._serialized_end=2581
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/store/v1beta1/listening.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/base/store/v1beta1/listening.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cosmos/base/store/v1beta1/listening.proto\x12\x19\x63osmos.base.store.v1beta1\"L\n\x0bStoreKVPair\x12\x11\n\tstore_key\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\x08\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\r\n\x05value\x18\x04 \x01(\x0c\x42*Z(github.com/cosmos/cosmos-sdk/store/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.store.v1beta1.listening_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/store/types'
  _globals['_STOREKVPAIR']._serialized_start=72
  _globals['_STOREKVPAIR']._serialized_end=148
# @@protoc_insertion_point(module_scope)



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.neurion.crucible.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryGetCreatorsRequest, QueryGetCreatorsResponse,
    QueryGetCreatorApplicationsRequest, QueryGetCreatorApplicationsResponse,
    QueryGetTaskRequest, QueryGetTaskResponse,
    QueryListAllTasksRequest, QueryListAllTasksResponse,
    QueryListTasksByStatusRequest, QueryListTasksByStatusResponse,
    QueryGetSubmissionRequest, QueryGetSubmissionResponse,
    QueryGetSubmissionByTaskCreatorRequest, QueryGetSubmissionByTaskCreatorResponse,
    QueryGetSubmissionByTaskRequest, QueryGetSubmissionByTaskResponse,
    QueryGetEncryptedProofOfOwnershipRequest, QueryGetEncryptedProofOfOwnershipResponse,
    QueryGetPlagiarismReportRequest, QueryGetPlagiarismReportResponse,
    QueryGetTaskRewardRequest, QueryGetTaskRewardResponse,
    QueryGetPendingCreatorApplicationsRequest, QueryGetPendingCreatorApplicationsResponse,
    QueryGetTaskStakeRequest, QueryGetTaskStakeResponse,
    QueryGetUnscoredSubmissionsByTaskRequest, QueryGetUnscoredSubmissionsByTaskResponse,
)
from neurionpy.crucible.interface import CrucibleQuery


class CrucibleRestClient(CrucibleQuery):
    """Crucible REST client implementing all query endpoints."""
    API_URL = "/neurion/crucible"

    def __init__(self, rest_api: RestClient):
        """
        Initialize the Crucible REST client.

        :param rest_api: RestClient instance for making HTTP requests.
        """
        self._rest_api = rest_api

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query module parameters.
        GET /neurion/crucible/params
        """
        response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(response, QueryParamsResponse())

    def GetCreators(self, request: QueryGetCreatorsRequest) -> QueryGetCreatorsResponse:
        """
        Query a list of creators.
        GET /neurion/crucible/get_creators
        """
        response = self._rest_api.get(f"{self.API_URL}/get_creators")
        return Parse(response, QueryGetCreatorsResponse())

    def GetCreatorApplications(
            self, request: QueryGetCreatorApplicationsRequest
    ) -> QueryGetCreatorApplicationsResponse:
        """
        Query creator applications for a given creator.
        GET /neurion/crucible/get_creator_applications/{creator}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_creator_applications/{request.creator}"
        )
        return Parse(response, QueryGetCreatorApplicationsResponse())

    def GetTask(self, request: QueryGetTaskRequest) -> QueryGetTaskResponse:
        """
        Query a task by its ID.
        GET /neurion/crucible/get_task/{id}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_task/{request.id}")
        return Parse(response, QueryGetTaskResponse())

    def ListAllTasks(self, request: QueryListAllTasksRequest) -> QueryListAllTasksResponse:
        """
        List all tasks with pagination.
        GET /neurion/crucible/list_all_tasks/{offset}/{limit}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/list_all_tasks/{request.offset}/{request.limit}"
        )
        return Parse(response, QueryListAllTasksResponse())

    def ListTasksByStatus(self, request: QueryListTasksByStatusRequest) -> QueryListTasksByStatusResponse:
        """
        List tasks by status with pagination.
        GET /neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/list_tasks_by_status/{request.status}/{request.offset}/{request.limit}"
        )
        return Parse(response, QueryListTasksByStatusResponse())

    def GetSubmission(self, request: QueryGetSubmissionRequest) -> QueryGetSubmissionResponse:
        """
        Query a submission by its ID.
        GET /neurion/crucible/get_submission/{id}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_submission/{request.id}")
        return Parse(response, QueryGetSubmissionResponse())

    def GetSubmissionByTaskCreator(
            self, request: QueryGetSubmissionByTaskCreatorRequest
    ) -> QueryGetSubmissionByTaskCreatorResponse:
        """
        Query submissions for a given task and creator.
        GET /neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_submission_by_task_creator/{request.task_id}/{request.creator}"
        )
        return Parse(response, QueryGetSubmissionByTaskCreatorResponse())

    def GetSubmissionByTask(
            self, request: QueryGetSubmissionByTaskRequest
    ) -> QueryGetSubmissionByTaskResponse:
        """
        Query submissions for a given task.
        GET /neurion/crucible/get_submission_by_task/{task_id}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_submission_by_task/{request.task_id}")
        return Parse(response, QueryGetSubmissionByTaskResponse())

    def GetEncryptedProofOfOwnership(
            self, request: QueryGetEncryptedProofOfOwnershipRequest
    ) -> QueryGetEncryptedProofOfOwnershipResponse:
        """
        Get encrypted proof of ownership.
        GET /neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_encrypted_proof_of_ownership/{request.key}/{request.plaintext}"
        )
        return Parse(response, QueryGetEncryptedProofOfOwnershipResponse())

    def GetPlagiarismReport(
            self, request: QueryGetPlagiarismReportRequest
    ) -> QueryGetPlagiarismReportResponse:
        """
        Query a plagiarism report by report ID.
        GET /neurion/crucible/get_plagiarism_report/{report_id}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_plagiarism_report/{request.report_id}")
        return Parse(response, QueryGetPlagiarismReportResponse())

    def GetTaskReward(self, request: QueryGetTaskRewardRequest) -> QueryGetTaskRewardResponse:
        """
        Query task reward for a given task and user.
        GET /neurion/crucible/get_task_reward/{task_id}/{user}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_task_reward/{request.task_id}/{request.user}"
        )
        return Parse(response, QueryGetTaskRewardResponse())

    def GetPendingCreatorApplications(
            self, request: QueryGetPendingCreatorApplicationsRequest
    ) -> QueryGetPendingCreatorApplicationsResponse:
        """
        Query pending creator applications.
        GET /neurion/crucible/get_pending_creator_applications
        """
        response = self._rest_api.get(f"{self.API_URL}/get_pending_creator_applications")
        return Parse(response, QueryGetPendingCreatorApplicationsResponse())

    def GetTaskStake(self, request: QueryGetTaskStakeRequest) -> QueryGetTaskStakeResponse:
        """
        Query task stake for a given task and user.
        GET /neurion/crucible/get_task_stake/{task_id}/{user}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_task_stake/{request.task_id}/{request.user}"
        )
        return Parse(response, QueryGetTaskStakeResponse())

    def GetUnscoredSubmissionsByTask(
            self, request: QueryGetUnscoredSubmissionsByTaskRequest
    ) -> QueryGetUnscoredSubmissionsByTaskResponse:
        """
        Query unscored submissions by task.
        GET /neurion/crucible/get_unscored_submissions_by_task/{task_id}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_unscored_submissions_by_task/{request.task_id}"
        )
        return Parse(response, QueryGetUnscoredSubmissionsByTaskResponse())


from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.neurion.sanctum.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryGetAvailableDatasetsRequest, QueryGetAvailableDatasetsResponse,
    QueryGetApprovedUsageRequestsRequest, QueryGetApprovedUsageRequestsResponse,
    QueryGetRewardRequest, QueryGetRewardResponse,
    QueryGetStakeRequest, QueryGetStakeResponse,
    QueryGetPendingDatasetsRequest, QueryGetPendingDatasetsResponse,
    QueryGetPendingUsageRequestsRequest, QueryGetPendingUsageRequestsResponse,
    QueryGetDatasetRequest, QueryGetDatasetResponse,
    QueryGetUsageRequestRequest, QueryGetUsageRequestResponse,
)
from neurionpy.sanctum.interface import SanctumQuery


class SanctumRestClient(SanctumQuery):
    """Sanctum REST client implementing all query endpoints."""
    API_URL = "/neurion/sanctum"

    def __init__(self, rest_api: RestClient):
        """
        Create Sanctum REST client.

        :param rest_api: RestClient instance for making HTTP requests.
        """
        self._rest_api = rest_api

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query the parameters of the Sanctum module.
        GET /neurion/sanctum/params
        """
        response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(response, QueryParamsResponse())

    def GetAvailableDatasets(self, request: QueryGetAvailableDatasetsRequest) -> QueryGetAvailableDatasetsResponse:
        """
        Query a list of available datasets.
        GET /neurion/sanctum/get_available_datasets?offset={offset}&limit={limit}
        """
        params = {"offset": request.offset, "limit": request.limit}
        response = self._rest_api.get(f"{self.API_URL}/get_available_datasets/{request.offset}/{request.limit}")
        return Parse(response, QueryGetAvailableDatasetsResponse())

    def GetApprovedUsageRequests(self,
                                 request: QueryGetApprovedUsageRequestsRequest) -> QueryGetApprovedUsageRequestsResponse:
        """
        Query a list of approved usage requests.
        GET /neurion/sanctum/get_approved_usage_requests
        """
        response = self._rest_api.get(f"{self.API_URL}/get_approved_usage_requests")
        return Parse(response, QueryGetApprovedUsageRequestsResponse())

    def GetReward(self, request: QueryGetRewardRequest) -> QueryGetRewardResponse:
        """
        Query reward for a given user.
        GET /neurion/sanctum/get_reward/{user}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_reward/{request.user}")
        return Parse(response, QueryGetRewardResponse())

    def GetStake(self, request: QueryGetStakeRequest) -> QueryGetStakeResponse:
        """
        Query stake for a given user.
        GET /neurion/sanctum/get_stake/{user}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_stake/{request.user}")
        return Parse(response, QueryGetStakeResponse())

    def GetPendingDatasets(self, request: QueryGetPendingDatasetsRequest) -> QueryGetPendingDatasetsResponse:
        """
        Query a list of pending datasets.
        GET /neurion/sanctum/get_pending_datasets
        """
        response = self._rest_api.get(f"{self.API_URL}/get_pending_datasets")
        return Parse(response, QueryGetPendingDatasetsResponse())

    def GetPendingUsageRequests(self,
                                request: QueryGetPendingUsageRequestsRequest) -> QueryGetPendingUsageRequestsResponse:
        """
        Query a list of pending usage requests for a given user.
        GET /neurion/sanctum/get_pending_usage_requests/{user}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_pending_usage_requests/{request.user}")
        return Parse(response, QueryGetPendingUsageRequestsResponse())

    def GetDataset(self, request: QueryGetDatasetRequest) -> QueryGetDatasetResponse:
        """
        Query a dataset by its ID.
        GET /neurion/sanctum/get_dataset/{id}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_dataset/{request.id}")
        return Parse(response, QueryGetDatasetResponse())

    def GetUsageRequest(self, request: QueryGetUsageRequestRequest) -> QueryGetUsageRequestResponse:
        """
        Query a usage request by its ID.
        GET /neurion/sanctum/get_usage_request/{id}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_usage_request/{request.id}")
        return Parse(response, QueryGetUsageRequestResponse())


from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.neurion.fusion.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryGetTaskRequest, QueryGetTaskResponse,
    QueryGetTaskRewardRequest, QueryGetTaskRewardResponse,
    QueryGetCreatorApplicantsRequest, QueryGetCreatorApplicantsResponse,
    QueryGetPendingCreatorApplicationsRequest, QueryGetPendingCreatorApplicationsResponse,
    QueryGetModelsByRoundRequest, QueryGetModelsByRoundResponse,
    QueryGetTaskStakeRequest, QueryGetTaskStakeResponse,
    QueryGetValidationTaskRequest, QueryGetValidationTaskResponse,
)
from neurionpy.fusion.interface import FusionQuery


class FusionRestClient(FusionQuery):
    """Fusion REST client implementing all query endpoints."""
    API_URL = "/neurion/fusion"

    def __init__(self, rest_api: RestClient):
        """
        Initialize the Fusion REST client.

        :param rest_api: RestClient instance for making HTTP GET requests.
        """
        self._rest_api = rest_api

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query module parameters.
        GET /neurion/fusion/params
        """
        response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(response, QueryParamsResponse())

    def GetTask(self, request: QueryGetTaskRequest) -> QueryGetTaskResponse:
        """
        Query a task by its ID.
        GET /neurion/fusion/get_task/{task_id}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_task/{request.task_id}")
        return Parse(response, QueryGetTaskResponse())

    def GetTaskReward(self, request: QueryGetTaskRewardRequest) -> QueryGetTaskRewardResponse:
        """
        Query task reward for a given task and user.
        GET /neurion/fusion/get_task_reward/{task_id}/{user}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_task_reward/{request.task_id}/{request.user}"
        )
        return Parse(response, QueryGetTaskRewardResponse())

    def GetCreatorApplicants(
        self, request: QueryGetCreatorApplicantsRequest
    ) -> QueryGetCreatorApplicantsResponse:
        """
        Query creator applicants for a given creator.
        GET /neurion/fusion/get_creator_applicants/{creator}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_creator_applicants/{request.creator}"
        )
        return Parse(response, QueryGetCreatorApplicantsResponse())

    def GetPendingCreatorApplications(
        self, request: QueryGetPendingCreatorApplicationsRequest
    ) -> QueryGetPendingCreatorApplicationsResponse:
        """
        Query pending creator applications.
        GET /neurion/fusion/get_pending_creator_applications
        """
        response = self._rest_api.get(f"{self.API_URL}/get_pending_creator_applications")
        return Parse(response, QueryGetPendingCreatorApplicationsResponse())

    def GetModelsByRound(self, request: QueryGetModelsByRoundRequest) -> QueryGetModelsByRoundResponse:
        """
        Query proposed models for a given task and round.
        GET /neurion/fusion/get_models_by_round/{task_id}/{round}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_models_by_round/{request.task_id}/{request.round}"
        )
        return Parse(response, QueryGetModelsByRoundResponse())

    def GetTaskStake(self, request: QueryGetTaskStakeRequest) -> QueryGetTaskStakeResponse:
        """
        Query task stake for a given task and user.
        GET /neurion/fusion/get_task_stake/{task_id}/{user}
        """
        response = self._rest_api.get(
            f"{self.API_URL}/get_task_stake/{request.task_id}/{request.user}"
        )
        return Parse(response, QueryGetTaskStakeResponse())

    def GetValidationTask(self, request: QueryGetValidationTaskRequest) -> QueryGetValidationTaskResponse:
        """
        Query a validation task by its ID.
        GET /neurion/fusion/get_validation_task/{id}
        """
        response = self._rest_api.get(f"{self.API_URL}/get_validation_task/{request.id}")
        return Parse(response, QueryGetValidationTaskResponse())


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from neurion.fusion import params_pb2 as neurion_dot_fusion_dot_params__pb2
from neurion.fusion import task_pb2 as neurion_dot_fusion_dot_task__pb2
from neurion.fusion import creator_application_pb2 as neurion_dot_fusion_dot_creator__application__pb2
from neurion.fusion import proposed_model_pb2 as neurion_dot_fusion_dot_proposed__model__pb2
from neurion.fusion import validation_task_pb2 as neurion_dot_fusion_dot_validation__task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aneurion/fusion/query.proto\x12\x0eneurion.fusion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bneurion/fusion/params.proto\x1a\x19neurion/fusion/task.proto\x1a(neurion/fusion/creator_application.proto\x1a#neurion/fusion/proposed_model.proto\x1a$neurion/fusion/validation_task.proto\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x16.neurion.fusion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"&\n\x13QueryGetTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"E\n\x14QueryGetTaskResponse\x12-\n\x04task\x18\x01 \x01(\x0b\x32\x14.neurion.fusion.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryGetTaskRewardRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\",\n\x1aQueryGetTaskRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"3\n QueryGetCreatorApplicantsRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"f\n!QueryGetCreatorApplicantsResponse\x12\x41\n\napplicants\x18\x01 \x03(\x0b\x32\".neurion.fusion.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"+\n)QueryGetPendingCreatorApplicationsRequest\"o\n*QueryGetPendingCreatorApplicationsResponse\x12\x41\n\napplicants\x18\x01 \x03(\x0b\x32\".neurion.fusion.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\">\n\x1cQueryGetModelsByRoundRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\r\n\x05round\x18\x02 \x01(\x04\"Y\n\x1dQueryGetModelsByRoundResponse\x12\x38\n\x06models\x18\x01 \x03(\x0b\x32\x1d.neurion.fusion.ProposedModelB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryGetTaskStakeRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\"*\n\x19QueryGetTaskStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\"+\n\x1dQueryGetValidationTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"d\n\x1eQueryGetValidationTaskResponse\x12\x42\n\x0fvalidation_task\x18\x01 \x01(\x0b\x32\x1e.neurion.fusion.ValidationTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\x91\n\n\x05Query\x12q\n\x06Params\x12\".neurion.fusion.QueryParamsRequest\x1a#.neurion.fusion.QueryParamsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/neurion/fusion/params\x12\x80\x01\n\x07GetTask\x12#.neurion.fusion.QueryGetTaskRequest\x1a$.neurion.fusion.QueryGetTaskResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/fusion/get_task/{task_id}\x12\xa0\x01\n\rGetTaskReward\x12).neurion.fusion.QueryGetTaskRewardRequest\x1a*.neurion.fusion.QueryGetTaskRewardResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_task_reward/{task_id}/{user}\x12\xb5\x01\n\x14GetCreatorApplicants\x12\x30.neurion.fusion.QueryGetCreatorApplicantsRequest\x1a\x31.neurion.fusion.QueryGetCreatorApplicantsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_creator_applicants/{creator}\x12\xd0\x01\n\x1dGetPendingCreatorApplications\x12\x39.neurion.fusion.QueryGetPendingCreatorApplicationsRequest\x1a:.neurion.fusion.QueryGetPendingCreatorApplicationsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_pending_creator_applications\x12\xae\x01\n\x10GetModelsByRound\x12,.neurion.fusion.QueryGetModelsByRoundRequest\x1a-.neurion.fusion.QueryGetModelsByRoundResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/neurion/fusion/get_models_by_round/{task_id}/{round}\x12\x8b\x01\n\x0cGetTaskStake\x12(.neurion.fusion.QueryGetTaskStakeRequest\x1a).neurion.fusion.QueryGetTaskStakeResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/neurion/fusion/get_task_stake\x12\xa4\x01\n\x11GetValidationTask\x12-.neurion.fusion.QueryGetValidationTaskRequest\x1a..neurion.fusion.QueryGetValidationTaskResponse\"0\x82\xd3\xe4\x93\x02*\x12(/neurion/fusion/get_validation_task/{id}B\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETCREATORAPPLICANTSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETCREATORAPPLICANTSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETMODELSBYROUNDRESPONSE'].fields_by_name['models']._loaded_options = None
  _globals['_QUERYGETMODELSBYROUNDRESPONSE'].fields_by_name['models']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETVALIDATIONTASKRESPONSE'].fields_by_name['validation_task']._loaded_options = None
  _globals['_QUERYGETVALIDATIONTASKRESPONSE'].fields_by_name['validation_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\030\022\026/neurion/fusion/params'
  _globals['_QUERY'].methods_by_name['GetTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/fusion/get_task/{task_id}'
  _globals['_QUERY'].methods_by_name['GetTaskReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskReward']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_task_reward/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetCreatorApplicants']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreatorApplicants']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_creator_applicants/{creator}'
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_pending_creator_applications'
  _globals['_QUERY'].methods_by_name['GetModelsByRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetModelsByRound']._serialized_options = b'\202\323\344\223\0027\0225/neurion/fusion/get_models_by_round/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['GetTaskStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskStake']._serialized_options = b'\202\323\344\223\002 \022\036/neurion/fusion/get_task_stake'
  _globals['_QUERY'].methods_by_name['GetValidationTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetValidationTask']._serialized_options = b'\202\323\344\223\002*\022(/neurion/fusion/get_validation_task/{id}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=290
  _globals['_QUERYPARAMSREQUEST']._serialized_end=310
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=312
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=384
  _globals['_QUERYGETTASKREQUEST']._serialized_start=386
  _globals['_QUERYGETTASKREQUEST']._serialized_end=424
  _globals['_QUERYGETTASKRESPONSE']._serialized_start=426
  _globals['_QUERYGETTASKRESPONSE']._serialized_end=495
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_start=497
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_end=555
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_start=557
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_end=601
  _globals['_QUERYGETCREATORAPPLICANTSREQUEST']._serialized_start=603
  _globals['_QUERYGETCREATORAPPLICANTSREQUEST']._serialized_end=654
  _globals['_QUERYGETCREATORAPPLICANTSRESPONSE']._serialized_start=656
  _globals['_QUERYGETCREATORAPPLICANTSRESPONSE']._serialized_end=758
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_start=760
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_end=803
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_start=805
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_end=916
  _globals['_QUERYGETMODELSBYROUNDREQUEST']._serialized_start=918
  _globals['_QUERYGETMODELSBYROUNDREQUEST']._serialized_end=980
  _globals['_QUERYGETMODELSBYROUNDRESPONSE']._serialized_start=982
  _globals['_QUERYGETMODELSBYROUNDRESPONSE']._serialized_end=1071
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_start=1073
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_end=1130
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_start=1132
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_end=1174
  _globals['_QUERYGETVALIDATIONTASKREQUEST']._serialized_start=1176
  _globals['_QUERYGETVALIDATIONTASKREQUEST']._serialized_end=1219
  _globals['_QUERYGETVALIDATIONTASKRESPONSE']._serialized_start=1221
  _globals['_QUERYGETVALIDATIONTASKRESPONSE']._serialized_end=1321
  _globals['_QUERY']._serialized_start=1324
  _globals['_QUERY']._serialized_end=2621
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/module/module.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/module/module.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"neurion/fusion/module/module.proto\x12\x15neurion.fusion.module\x1a cosmos/app/v1alpha1/module.proto\"5\n\x06Module\x12\x11\n\tauthority\x18\x01 \x01(\t:\x18\xba\xc0\x96\xda\x01\x12\n\x10neurion/x/fusionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.module.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001\022\n\020neurion/x/fusion'
  _globals['_MODULE']._serialized_start=95
  _globals['_MODULE']._serialized_end=148
# @@protoc_insertion_point(module_scope)
